# coding=utf-8
import requests


# api-endpoint 
URL = "https://my.business.blockpays.io/client/api/v1/"
APIKEY = '' 
HEADERS = {}
def setApiKey(apikey):
    global APIKEY
    APIKEY = apikey
    global HEADERS
    HEADERS = { 
            'User-Agent' :'Blockpays/v1.0.0', 
            'accountId' : APIKEY, 
            'Content-Type' : 'application/json', 
            'origins' : '*',
            'accept' : '*/*'
        }

def getCurrencies(params):
        
    # sending get request and saving the response as response object 
    r = requests.post(url = URL + 'getCurrencies', json = params,headers = HEADERS) 
    
    # extracting data in json format 
    
    return r.json()

def isValidAddress(params):
       
    # sending get request and saving the response as response object 
    r = requests.post(url = URL + 'isValidAddress', json = params,headers = HEADERS) 
    
    # extracting data in json format 
    
    return r.json()
    


from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

setup_args = dict(
    name='pyblockpaysio',
    version='1.0.1',
    description='This library let integrate your application to our platform then use all service of cripto currencies that us have for you',
    long_description_content_type="text/markdown",
    long_description=README,
    license='MIT',
    packages=find_packages(),
    author = 'Carlos Torres - Labsatoshi',
    author_email = 'carlos.torres@labsatoshi.com',
    url = 'https://gt.globalcoin.co/ctorres/pyblockpays',
    download_url = 'https://gt.globalcoin.co/ctorres/pyblockpays/-/tree/1.0.0',
    keywords = ['blockpays', 'payments', 'criptos']
)

install_requires = [
    'requests'
]

if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)